import PropTypes from "prop-types";
import Link from "next/link";
import cn from "classnames";
import styles from "./styles.module.css";

const Button = ({
  disabled = false,
  variant,
  children,
  className,
  ...props
}) => {
  const classNames = cn(styles["btn"], {
    [styles[variant]]: variant,
    [styles[className]]: className,
    [styles.disabled]: disabled,
  });

  return props.href != undefined ? (
    <Link className={classNames} {...props}>
      {children}
    </Link>
  ) : (
    <button className={classNames} {...props}>
      {children}
    </button>
  );
};

Button.propTypes = {
  variant: PropTypes.oneOf(["primary", "secondary"]),
  disabled: PropTypes.bool,
};

export default Button;
